@@ -24,11 +24,15 @@
 #include "main-options-widget-googletalk.h"
 #include "main-options-widget-facebook.h"
 #include "main-options-widget-msn.h"
+#include "main-options-widget-kde-talk.h"
 #include "server-settings-widget.h"
 #include "proxy-settings-widget.h"
 
 #include <KCMTelepathyAccounts/AbstractAccountParametersWidget>
 #include <KCMTelepathyAccounts/GenericAdvancedOptionsWidget>
+#include <KCMTelepathyAccounts/ParameterEditModel>
+
+#include <TelepathyQt/ProtocolParameter>
 
 
 GabbleAccountUi::GabbleAccountUi(const QString &serviceName, QObject *parent)
@@ -67,12 +71,19 @@ AbstractAccountParametersWidget *GabbleAccountUi::mainOptionsWidget(
         ParameterEditModel *model,
         QWidget *parent) const
 {
+    QModelIndex resourceIndex = model->indexForParameter(model->parameter(QLatin1String("resource")));
+    if (resourceIndex.isValid() && model->data(resourceIndex, ParameterEditModel::ValueRole).toString().isEmpty()) {
+        model->setData(resourceIndex, QString::fromLatin1("kde-telepathy"), ParameterEditModel::ValueRole);
+    }
+
     if (m_serviceName == QLatin1String("google-talk")) {
-	return new MainOptionsWidgetGoogleTalk(model, parent);
+        return new MainOptionsWidgetGoogleTalk(model, parent);
     } else if (m_serviceName == QLatin1String("facebook")) {
         return new MainOptionsWidgetFacebook(model, parent);
     } else if (m_serviceName == QLatin1String("msn-xmpp")) {
         return new MainOptionsWidgetMSN(model, parent);
+    } else if (m_serviceName == QLatin1String("kde-talk")) {
+        return new MainOptionsWidgetKDETalk(model, parent);
     } else {
         return new MainOptionsWidget(model, parent);
     }
